Example Scripts
===============

- <adjust_nr_state.py>
- <credit_curves.py>
- <empirical_transition_matrix.py>
- <estimate_matrix.py>  
- <fix_multiperiod_matrix.py>
- <generate_full_multiperiod_set.py>
- <generate_synthetic_data.py>
- <generate_visuals.py>
- <matrix_from_cohort_data.py>
- <matrix_from_duration_data.py>
- <matrix_lendingclub.py>
- <matrix_operations.py>
- <matrix_set_lendingclub.py>
- <matrix_set_operations.py>
- <state_space_operations.py>
